PgConfig

Struct PgConfig 

pub struct PgConfig {
    pub host: String,
    pub port: u16,
    pub user: String,
    pub password: String,
    pub database: String,
    pub socket_dir: Option<String>,
}
Connection configuration.

Fields

host: Stringport: u16user: Stringpassword: Stringdatabase: Stringsocket_dir: Option<String>

Optional Unix domain socket directory. When set, connect via <socket_dir>/.s.PGSQL.<port> instead of TCP.

Implementations

Source

impl PgConfig

pub fn new( host: &str, port: u16, user: &str, password: &str, database: &str, ) -> Self

pub fn with_socket_dir(self, dir: &str) -> Self

Set a Unix domain socket directory for the connection. The actual socket path will be <dir>/.s.PGSQL.<port>.

pub fn from_url(url: &str) -> PgResult<Self>

Parse from a connection string: postgres://user:pass@host:port/db

For Unix domain sockets, use a path as the host: postgres://user:pass@%2Fvar%2Frun%2Fpostgresql/db (URL-encoded slashes) or postgres://user:pass@/db?host=/var/run/postgresql