PgPoolConfig

Struct PgPoolConfig 

pub struct PgPoolConfig {
    pub max_size: usize,
    pub min_size: usize,
    pub max_lifetime: Option<Duration>,
    pub idle_timeout: Option<Duration>,
    pub checkout_timeout: Option<Duration>,
    pub connection_timeout: Option<Duration>,
    pub test_on_checkout: bool,
    pub validation_query: String,
    pub auto_reconnect: bool,
}
Pool configuration options.

Fields

max_size: usize

Maximum number of connections in this pool.

min_size: usize

Minimum number of connections to maintain (eagerly created).

max_lifetime: Option<Duration>

Maximum lifetime of a connection before it is closed and recreated.

idle_timeout: Option<Duration>

Close connections that have been idle for longer than this.

checkout_timeout: Option<Duration>

Maximum time to wait when all connections are busy (get()).

connection_timeout: Option<Duration>

Maximum time to wait when creating a new connection.

test_on_checkout: bool

If true, run a validation query before returning a connection from the pool.

validation_query: String

The query to use for validation (default: "SELECT 1").

auto_reconnect: bool

If true, automatically reconnect when a connection is found to be dead.

Implementations

Source

impl PgPoolConfig

pub fn new() -> Self

Create a new pool config with defaults.

pub fn max_size(self, size: usize) -> Self

Set the maximum pool size.

pub fn min_size(self, size: usize) -> Self

Set the minimum pool size.

pub fn max_lifetime(self, duration: Duration) -> Self

Set the maximum connection lifetime.

pub fn idle_timeout(self, duration: Duration) -> Self

Set the idle timeout.

pub fn checkout_timeout(self, duration: Duration) -> Self

Set the checkout timeout (how long get() waits for a free connection).

pub fn connection_timeout(self, duration: Duration) -> Self

Set the connection timeout.

pub fn test_on_checkout(self, enable: bool) -> Self

Enable or disable test-on-checkout.

pub fn no_max_lifetime(self) -> Self

Disable max lifetime.

pub fn no_idle_timeout(self) -> Self

Disable idle timeout.